#!/usr/bin/perl
#-----------------------------------------------------------------------------#
# X11::GUITest ($Id: ScriptTemplate.pl,v 1.1 2003/12/13 16:58:32 ctrondlp Exp $)
# Notes: 
#-----------------------------------------------------------------------------#

## Pragmas/Directives/Diagnostics ##
use strict;
use warnings;

## Imports (use [MODULE] qw/[IMPORTLIST]/;) ##
use X11::GUITest qw/

/;

## Constants (sub [CONSTANT]() { [VALUE]; }) ##

## Variables (my [SIGIL][VARIABLE] = [INITIALVALUE];) ##

## Core ##
print "$0 : Script Start\n";


print "This script serves as a template.\n";


print "$0 : Script End (Success)\n";

## Subroutines ##
